@@ -6,7 +6,7 @@ package Mite::Attribute;
 use Mite::Miteception qw( -all !lazy );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.006011';
+our $VERSION   = '0.006012';
 
 has _order =>
   is            => rw,
@@ -65,12 +65,12 @@ has [ 'reader', 'writer', 'accessor', 'clearer', 'predicate', 'lvalue', 'local_w
 
 has isa =>
   is            => bare,
-  isa           => Str|Object,
+  isa           => Str|Ref,
   reader        => '_%s'; # collision with UNIVERSAL::isa
 
 has does =>
   is            => bare,
-  isa           => Str|Object,
+  isa           => Str|Ref,
   reader        => '_%s'; # collision with Mite's does method
 
 has type =>
@@ -329,6 +329,20 @@ sub _build_type {
     my $type;
     if ( ref $string ) {
         $type = $string;
+
+        if ( blessed $type and not $type->isa( 'Type::Tiny' ) ) {
+            if ( $type->can( 'to_TypeTiny' ) ) {
+                $type = $type->to_TypeTiny;
+            }
+            else {
+                require Types::TypeTiny;
+                $type = $type->Types::TypeTiny::to_TypeTiny;
+            }
+        }
+        elsif ( not blessed $type ) {
+            require Types::TypeTiny;
+            $type = Types::TypeTiny::to_TypeTiny( $type );
+        }
     }
     else {
         require Type::Utils;
